use utoipa::OpenApi;
use utoipa_swagger_ui::SwaggerUi;

// Because apparently the OpenApi macro can't import these on its own
// if the routes are not in the same location as the router
use crate::routes::{
    __path_index,
    channel::{
        __path_delete_channel, __path_get_channel, __path_get_channel_videos, __path_list_channels,
        __path_update_channel, __path_upload_channel,
    },
    comment::__path_get_video_comments,
    video::{
        __path_delete_video, __path_get_video, __path_list_videos, __path_update_video,
        __path_upload_video,
    },
};

#[derive(OpenApi)]
#[openapi(
    paths(
        index,
        list_channels,
        list_videos,
        upload_video,
        upload_channel,
        update_channel,
        update_video,
        delete_channel,
        delete_video,
        get_video,
        get_channel,
        get_video_comments,
        get_channel_videos
    ),
    info(
        title = "Almond API",
        description = "Interface to archive YouTube videos."
    )
)]
struct ApiDoc;

pub fn docs_router() -> SwaggerUi {
    SwaggerUi::new("/docs").url("/api-doc/openapi.json", ApiDoc::openapi())
}
